@@ -38,6 +38,11 @@ PROTOCOLS = (
     ("IPv6", _("IPv6")),
 )
 
+MTUS = (
+    (1500, "1500"),
+    (9000, "9000"),
+)
+
 RATIOS = (
     ("", _("Not Disclosed")),
     ("Not Disclosed", _("Not Disclosed")),
@@ -338,7 +343,7 @@ REGION_MAPPING = [
     },
     {
         "code": "EG",
-        "continent": "MIddle East",
+        "continent": "Middle East",
     },
     {
         "code": "ER",
@@ -938,6 +943,6 @@ REGION_MAPPING = [
     },
     {
         "code": "PR",
-        "continent": "America",
+        "continent": "North America",
     },
 ]
